<template>
  <div>
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @tableRowClassName="tableRowClassName"
      :uploadInfo="uploadInfo"
      :isShowHide="true"
      :prelang="prelang"
      :options="options"
      :bottomOffset="255"
      :paramObj="paramObj"
      :ajaxFun="ajaxFun"
      ref="returnDetailTable"
    >
      <template #toolbar></template>
    </ttable>

    <!-- 弹窗, 新增 / 修改 -->
    <table-form
      v-if="addOrUpdateVisible"
      ref="addOrUpdate"
      @refreshDataList="getData"
    ></table-form>
  </div>
</template>

<script>
import {
  fetchListReturnDetail,
  delReturnDetail,
  submit,
  accomplish
} from '@/api/warehouse/return'
import { loadLocation } from '@/api/warehouse/location'
import TableForm from './return-detail-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table'

export default {
  props: {
    mainId: {
      type: Number,
      default: 0
    },
    status: {
      type: String,
      default: '未下发'
    },
    visible: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      paramObj: {},
      ajaxFun: fetchListReturnDetail,
      locations: [],
      formItemVisible: true,
      // 退库清单
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: false, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '100',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          {
            minWidth: '100',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'specs',
            label: '规格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'returnQty',
            label: '退库数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'confirmQty',
            label: '确认数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'locationId',
            label: '接收库位',
            sort: true,
            isTrue: true,
            formatter: this.formatLocation,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.locations
            }
          },
          {
            minWidth: '100',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: null,
        operator: null,
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 120,
          minWidth: 120
        }
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    TableForm,
    ttable
  },
  watch: {
    mainId: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.paramObj = { returnMainId: newValue }
          this.$nextTick(() => {
            this.getData()
          })
        }
      },
      immediate: true
    },
    visible: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.paramObj = { returnMainId: this.mainId }
          this.$nextTick(() => {
            this.getData()
          })
        }
      },
      immediate: true
    },
    status: {
      handler(newValue, oldValue) {
        if (newValue == '已处理') {
          this.formItemVisible = true
          this.table.operator = null
          this.table.toolbar = null
        } else if (newValue == '已下发') {
          this.formItemVisible = false
          this.table.operator = [
            {
              text: '修改',
              icon: 'el-icon-edit',
              type: 'text',
              size: 'small',
              fun: this.addOrUpdateHandle
            }
          ]
          this.table.toolbar = [
            {
              text: '完成处理',
              icon: 'el-icon-circle-check',
              type: 'primary',
              fun: this.accomplish
            }
          ]
        } else if (newValue == '未下发') {
          this.formItemVisible = true
          this.table.operator = [
            {
              text: '修改',
              icon: 'el-icon-edit',
              type: 'text',
              size: 'small',
              fun: this.addOrUpdateHandle
            },
            {
              text: '删除',
              icon: 'el-icon-delete',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ]
          this.table.toolbar = [
            {
              text: '新增',
              icon: 'el-icon-plus',
              type: 'primary',
              fun: this.addOrUpdateHandle
            },
            {
              text: '提交',
              icon: 'el-icon-upload2',
              type: 'primary',
              fun: this.submit
            }
          ]
        }
      },
      immediate: true
    }
  },
  created() {
    this.initLocations()
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取库位
    initLocations() {
      loadLocation().then((res) => {
        this.locations = JSON.parse(
          JSON.stringify(res.data.data)
            .replace(/id/g, 'value')
            .replace(/locNo/g, 'label')
        )
      })
    },
    // 提交退库明细
    submit() {
      if (this.mainId) {
        this.$confirm('是否退库申请', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal: false,
          type: 'warning'
        }).then(() => {
          submit(this.mainId).then((response) => {
            this.$message.success('提交成功')
            this.getData()
            this.$emit('refreshDataList')
          })
        })
      } else {
        this.$message.error('请先保存')
      }
    },
    // 完成处理
    accomplish() {
      this.$confirm('是否完成处理', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      }).then(() => {
        accomplish(this.mainId).then((response) => {
          this.$message.success('处理成功')
          this.getData()
          this.$emit('refreshDataList')
        })
      })
    },
    // 获取数据列表
    getData() {
      if (this.$refs.returnDetailTable !== undefined) {
        this.$refs.returnDetailTable.getDataList()
      }
    },
    /*  getDataList() {
        this.dataListLoading = true
        fetchListReturnDetail(Object.assign(
          {
            current: this.table.currentPage,
            size: this.table.pageSize,
            dateTimeFilters: JSON.stringify(this.dateTimeFilters),
            returnMainId: this.mainId
          },
          this.queryForm
        )).then(response => {
          this.table.data = response.data.data.records
          this.table.total = response.data.data.total
          this.dataListLoading = false
        })

      }, */
    // 新增 / 修改
    addOrUpdateHandle(row) {
      if (!this.mainId) {
        this.$message.error('请先保存')
        return
      }
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(
          row ? row.id : row,
          this.mainId,
          this.formItemVisible
        )
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delReturnDetail(row ? row.id : row)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    // table自带事件
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    tableRowClassName(row, callback) {
      if (row.returnQty != row.confirmQty) {
        callback('warning-row')
      } else {
        callback('')
      }
    },

    // 表格字段格式化
    formatLocation(row, column, cellValue) {
      for (let i = 0, len = this.locations.length; i < len; i++) {
        if (cellValue == this.locations[i].value) {
          return this.locations[i].label
        }
      }
    }
  }
}
</script>
